@@ -26,7 +26,7 @@ qsa_of_interest = ['acl', 'cors', 'defaultObjectAcl', 'location', 'logging',
                    'adp', 'asyntask', 'querytask', 'domain',
                    'storageClass',
                    'websiteConfig',
-                   'compose', 'quota', 'policy', 'crr', 'fetch', 'append']
+                   'compose', 'quota', 'policy', 'crr', 'fetch', 'append', 'mirror']
 
 
 def url_encode(key):
