@@ -800,8 +800,8 @@ class Bucket(object):
         else:
             raise S3ResponseError(response.status, response.reason, body)
 
-    def set_bucket_crr(self, targetBucket, deleteMarkerStatus=None, prefix=None, headers=None):
-        replicate = BucketCrossReplicate(targetBucket, deleteMarkerStatus, prefix)
+    def set_bucket_crr(self, targetBucket, deleteMarkerStatus='Disabled', prefix_list=None, headers=None):
+        replicate = BucketCrossReplicate(targetBucket, deleteMarkerStatus, prefix_list)
         if headers is None:
             headers = {}
         headers['Content-Type'] = 'text/xml'
