@@ -104,7 +104,7 @@ class Connection(object):
     def __init__(self, access_key_id, access_key_secret, host="",
                  port=80, provider='kss', security_token=None, profile_name=None, path='/',
                  is_secure=False, debug=0, calling_format=SubdomainCallingFormat, domain_mode=False,
-                 local_encrypt=False, local_key_path="", timeout=10):
+                 local_encrypt=False, local_key_path="", timeout=10, ua_addon=''):
         """
         :param access_key_id: 金山云提供的ACCESS KEY ID
         :param access_key_secret: 金山云提供的SECRET KEY ID
@@ -126,6 +126,7 @@ class Connection(object):
         self.local_encrypt = local_encrypt
         self.key = ""
         self.timeout = timeout
+        self.ua_addon = ua_addon
         if (self.is_secure):
             self.protocol = 'https'
             if self.port == 80:
@@ -176,7 +177,7 @@ class Connection(object):
         resp = make_request(self.host, self.port, self.access_key_id,
                             self.access_key_secret, method, bucket, key,
                             query_args, headers, data, metadata, is_secure=self.is_secure, domain_mode=self.domain_mode,
-                            timeout=timeout)
+                            timeout=timeout, ua_addon=self.ua_addon)
 
         return resp
 
