@@ -14,6 +14,8 @@ try:
 except ImportError:
     import urllib as parse  # for Python 2
 
+sdk_version = '1.5.0'
+
 def get_utf8_value(value):
     if not six.PY2 and isinstance(value, bytes):
         return value
@@ -137,4 +139,10 @@ def compute_base64_md5_digest(data):
     base64_digest = encodebytes(m.digest()).decode('utf-8')
     if base64_digest[-1] == '\n':
         base64_digest = base64_digest[0:-1]
-    return base64_digest
\ No newline at end of file
+    return base64_digest
+
+def get_default_user_agent():
+    # import platform
+    # platform.version()
+    # platform.version()
+    return 'PythonSDK/' + sdk_version
